@@ -1,6 +1,7 @@
 import logging
 import os
 import os.path
+import platform
 import shlex
 import shutil
 import subprocess
@@ -18,6 +19,12 @@ __all__ = ['VaultLib', 'VaultEditor']
 LOGGER = logging.getLogger(__name__)
 
 
+if platform.system() == 'Windows':
+  DEFAULT_EDITOR = 'notepad'
+else:
+  DEFAULT_EDITOR = 'nano'
+
+
 b_HEADER = b'$ANSIBLE_VAULT'
 
 
@@ -550,7 +557,7 @@ class VaultEditor:
     shutil.move(src, dest)
 
   def _editor_shell_command(self, filename):
-    env_editor = os.environ.get('EDITOR', 'nano')
+    env_editor = os.environ.get('EDITOR', DEFAULT_EDITOR)
     editor = shlex.split(env_editor)
     editor.append(filename)
 
